utils::globalVariables(c(".", "image_path"))

#' @keywords internal
#' @importFrom purrr %>%
#' @import data.table
"_PACKAGE"
